@@ -128,6 +128,7 @@ from .smotri import (
     SmotriIE,
     SmotriCommunityIE,
     SmotriUserIE,
+    SmotriBroadcastIE,
 )
 from .sohu import SohuIE
 from .soundcloud import SoundcloudIE, SoundcloudSetIE, SoundcloudUserIE
@@ -210,6 +211,7 @@ from .youtube import (
     YoutubeWatchLaterIE,
     YoutubeFavouritesIE,
     YoutubeHistoryIE,
+    YoutubeTopListIE,
 )
 from .zdf import ZDFIE
 
